%global _hardened_build 1

# Make reproducible builds possible
%global source_date_epoch_from_changelog 0
%global clamp_mtime_to_source_date_epoch 1
%global use_source_date_epoch_as_buildtime 1
%define _buildhost apkg

%{!?_syprefix: %define _syprefix /opt/symas }
%{!?_etcfix: %define _etcfix %{_syprefix}/etc }
%{!?_sylibdir: %define _sylibdir %{_syprefix}/lib }
%{!?_varfix: %define _varfix /var/symas }
%define _cflags "-O2 -g"

%if 0%{?suse_version}
# We don't seem to have %{dist} in SUSEs, define our own
%{!?dist: %define dist .sles15 }
%endif

Summary: Utilities from the general purpose cryptography library with TLS implementation
Name: symas-openssl
Version: 3.0.14
Release: 1%{?dist}
License: Apache-2.0
Source: %{name}-v%{version}.tar.xz

URL: http://openssl.org
VCS: https://git.symas.net/symas-public/openssl.git

# Apparently distro setup should fill this in, but can't see where,
# Fake ours from dist and strip the leading dot
Distribution: %(echo %{?dist} | tr -d .)

AutoReqProv: no
# BuildRequires one at a time, microdnf doesn't support comma separated dependencies
BuildRequires: symas-buildtools >= 1.0.4
BuildRequires: gcc
BuildRequires: coreutils
BuildRequires: make
BuildRequires: sed
BuildRequires: zlib-devel
BuildRequires: /usr/bin/cmp
%if 0%{?suse_version}
BuildRequires: perl
%else
BuildRequires: perl-interpreter
%endif
BuildRequires: lksctp-tools-devel
BuildRequires: /usr/bin/rename
BuildRequires: /usr/bin/pod2man
BuildRequires: /usr/sbin/sysctl
BuildRequires: perl(Test::Harness)
BuildRequires: perl(Test::More)
BuildRequires: perl(Math::BigInt)
BuildRequires: perl(Module::Load::Conditional)
BuildRequires: perl(File::Temp)
BuildRequires: perl(Time::HiRes)
BuildRequires: perl(IPC::Cmd)
BuildRequires: perl(Pod::Html)
BuildRequires: perl(Digest::SHA)
BuildRequires: perl(FindBin)
BuildRequires: perl(lib)
BuildRequires: perl(File::Compare)
BuildRequires: perl(File::Copy)
BuildRequires: perl(bigint)
Requires: coreutils
Requires: symas-openssl-libs = %{version}-%{release}

%description
The OpenSSL toolkit provides support for secure communications between
machines. OpenSSL includes a certificate management tool and shared
libraries which provide various cryptographic algorithms and
protocols.

%prep
%setup -qn %{name}-v%{version}

%build
# OpenSSL has a weird combination of arch/cpu options as input, put only the
# ones we care about
sslarch=%{_os}-%{_target_cpu}
%ifarch aarch64
sslarch=linux-aarch64
%endif
%ifarch ppc64le
sslarch="linux-ppc64le"
%endif

HASHBANGPERL=/usr/bin/perl ./Configure \
    no-idea enable-ec_nistp_64_gcc_128 no-mdc2 no-rc5 no-egd \
    --debug %{_cflags} \
    --prefix=%{_syprefix} --libdir=lib --openssldir=%{_syprefix}/ssl \
    shared ${sslarch} -Wl,-rpath,%{_sylibdir}
make depend
make all

%check
make test

%install
make install DESTDIR=%{buildroot} STRIP_OPTS=""
rm -rf %{buildroot}%{_syprefix}/share/doc/openssl/html/
rm -rf %{buildroot}%{_sylibdir}/*.a
install -m 0644 CHANGES.md %{buildroot}%{_syprefix}/share/doc/openssl/
install -m 0644 LICENSE.txt %{buildroot}%{_syprefix}/share/doc/openssl/
install -m 0644 NEWS.md %{buildroot}%{_syprefix}/share/doc/openssl/
install -m 0644 README.md %{buildroot}%{_syprefix}/share/doc/openssl/

%package libs
Summary: OpenSSL Libaries
AutoReqProv: no

%description libs
The symas-openssl-libs package contains the openssl libraries

%package devel
Summary: openssl Development
Requires: symas-openssl-libs = %{version}-%{release}
AutoReqProv: no

%description devel
The openssl-devel package contains the linking libraries and include files


%files
%defattr(-,root,root)
%{_syprefix}/bin
%{_syprefix}/ssl
%{_syprefix}/share/man/man1
%{_syprefix}/share/man/man5
%{_syprefix}/share/man/man7

%files libs
%defattr(-,root,root)
%{_sylibdir}/*.so.*
%{_sylibdir}/engines-3
%{_sylibdir}/ossl-modules
%{_syprefix}/share/man/man3
%{_syprefix}/share/doc/openssl

%files devel
%defattr(-,root,root)
%{_syprefix}/include
%{_sylibdir}/pkgconfig/*.pc
%{_sylibdir}/*.so

%changelog
* Mon Jul 22 2024 Symas Support <support@symas.com> - 3.0.14-1
- OpenSSL 3.0.14-1 release
* Tue Jun 04 2024 Symas Support <support@symas.com> - 3.0.13-1
- OpenSSL 3.0.13-1 release
- Switch to apkg for packaging
* Thu May 18 2023 Symas Support <support@symas.com> - 3.0.8-1
- OpenSSL 3.0.8-1 release
* Fri Nov 11 2022 Symas Support <support@symas.com> - 1.1.1s-1
- OpenSSL 1.1.1s release
* Thu Jun 23 2022 Symas Support <support@symas.com> - 1.1.1p-1
- OpenSSL 1.1.1p release
* Fri Jun 03 2022 Symas Support <support@symas.com> - 1.1.1o-1
- OpenSSL 1.1.1o release with updated test certificates
- Update expired SCT certificates patch
- ct_test.c Update the epoch time patch
* Tue Nov 16 2021 Symas Support <support@symas.com> - 1.1.1l-2
- Install LICENSE, CHANGES, NEWS, and README files
* Tue Aug 24 2021 Symas Support <support@symas.com> - 1.1.1l-1
- OpenSSL 1.1.1l release
* Mon May 24 2021 Symas Support <support@symas.com> - 1.1.1k-2
- Use odd Symas OpenLDAP Gold path for SSL dir
* Tue Apr 6 2021 Symas Support <support@symas.com> - 1.1.1k-1
- initial packaging
